package net.knarcraft.ffmpegconverter.streams;

import org.jetbrains.annotations.NotNull;

/**
 * An object describing a generic video file stream
 */
public interface StreamObject {

    /**
     * Gets the name of the stream codec
     *
     * @return <p>Codec name.</p>
     */
    @NotNull
    String getCodecName();

    /**
     * Gets the absolute index of a stream object
     *
     * @return <p>Absolute index.</p>
     */
    int getAbsoluteIndex();

    /**
     * Gets the index of the input file this stream belongs to
     *
     * <p>This is the first number given to a map argument in order to map this stream to the output file.</p>
     *
     * @return <p>The input index of this stream</p>
     */
    int getInputIndex();

    /**
     * Gets the relative index of a stream object (kth element of codec type)
     *
     * @return <p>Relative index.</p>
     */
    int getRelativeIndex();

    /**
     * Gets the language of the audio or subtitle stream
     *
     * @return <p>The language of the audio or subtitle stream.</p>
     */
    @NotNull
    String getLanguage();

    /**
     * Gets whether this stream is marked as the default stream of its type
     *
     * @return <p>True if this stream is marked as default</p>
     */
    boolean isDefault();

    /**
     * Gets the stream type of this stream object
     *
     * @return <p>The stream type for this stream</p>
     */
    @NotNull
    StreamType getStreamType();

    /**
     * Gets the title of the subtitle stream
     *
     * @return <p>The title of the subtitle stream.</p>
     */
    @NotNull
    String getTitle();

}
